@@ -10,9 +10,10 @@
 
 #include <stdio.h>
 #include <stdlib.h>
+#include <pthread.h>
 
 #include "config.h"
-#include "id_record.h"
+#include "record.h"
 #include "operators.h"
 #include "dynamic_array.h"
 #include "hash_table.h"
@@ -27,7 +28,7 @@ struct index_lsh {
 	struct hash_table mapper;
 	struct smac_allocator storage;
 	size_t hash_size, dimensions;
-	
+	pthread_mutex_t mutex;
 };
 
 struct index_lsh init_lsh(const char * mapping_filename, const char * data_filename, size_t hash_size, size_t dimensions);
@@ -36,18 +37,20 @@ struct index_lsh * init_lsh_heap(const char * mapping_filename, const char * dat
 
 void lsh_add(struct index_lsh *, struct id_record * uid, DATA_TYPE * value, size_t value_size);
 
-size_t lsh_get(struct index_lsh *, DATA_TYPE * value, size_t value_size, size_t max_buffer_size, struct id_record * result_buffer);
+size_t lsh_get(struct index_lsh *, DATA_TYPE * value, size_t value_size, size_t max_buffer_size, void * result_buffer);
 
 void lsh_delete(struct index_lsh *, struct id_record * id_to_delete);
 
-void lsh_quick_delete(struct index_lsh * index, struct id_record * id_to_delete, DATA_TYPE * value, size_t value_size) ;
-
 void lsh_delete_helper(struct index_lsh * index, char * id_to_delete );
 
 void lsh_free(struct index_lsh *);
 
 void lsh_heap_free(struct index_lsh *);
 
+unsigned long lsh_get_uid_from_result(struct index_lsh * lsh, void * result, size_t index, char * uid);
+
+void lsh_get_vector_from_result(struct index_lsh * lsh, void * result, size_t index, DATA_TYPE * vector);
+
 void debug_print(struct index_lsh *);
 
 #endif /* index_lsh_h */
